@@ -89,6 +89,10 @@ INSPIRE_PARSER_KEYWORDS = {
     # Conference number
     'cnum': 'confnumber',
 
+    # Control number
+    'control_number': 'control_number',
+    'recid': 'control_number',
+
     # Country
     'country': 'country',
     'cc': 'country',
@@ -128,6 +132,10 @@ INSPIRE_PARSER_KEYWORDS = {
     'experiment': 'experiment',
     'exp': 'experiment',
 
+    # Field-code
+    'fc': 'field-code',
+    'field-code': 'field-code',
+
     # First-Author
     'first-author': 'first-author',
     'firstauthor': 'first-author',
@@ -137,6 +145,9 @@ INSPIRE_PARSER_KEYWORDS = {
     'fulltext': 'fulltext',
     'ft': 'fulltext',
 
+    # SPIRES identifiers
+    'irn': 'irn',
+
     # Job related
     'position': 'title',
     'region': 'region',
@@ -168,9 +179,6 @@ INSPIRE_PARSER_KEYWORDS = {
     # rawref
     'rawref': 'rawref',
 
-    # recid
-    'recid': 'recid',
-
     # Reference
     'citation': 'reference',
     'jour-vol-page': 'reference',
@@ -202,7 +210,7 @@ INSPIRE_PARSER_KEYWORDS = {
     't': 'title',
 
     # texkey
-    'texkey': 'texkey',
+    'texkey': 'texkeys',
 
     # Topcite, i.e. citation count
     # Cited used to be for Invenio style syntax while topcite for SPIRES
